Optical Phenomena
=================

Rayleigh Scattering
-------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    rayleigh_scattering
    sd_rayleigh_scattering
    scattering_cross_section

``colour.phenomena``

.. currentmodule:: colour.phenomena

.. autosummary::
    :toctree: generated/

    rayleigh_optical_depth
